define("financial/scripts/model/model.js", function (require, exports, module) {
    /**
     * model层实现，主要解决以下问题
     * 1、调用后台接口  2、缓存数据  3、为View提供一致的数据
     * model模块需要在commom.js中require一下
     */

    // 缓存常用的数据(对接口返回的原始数据，进行加工后的数据)
    var dataStore = {
        // 员工id
        "staffId": $.getLStorageInfo("staffId") || $.getLStorageInfo("userId"),
        "userId":  $.getLStorageInfo("userId") || $.getLStorageInfo("staffId"),
        // cache
        "myCache": {},

        // 二维码数据缓存列表，避免重复生成占用资源
        "qrBase64Map": {},

        // 当天的沪深300收盘价做缓存
        "hushen300Date" : {},
        "hushen300Map" : {},

        //我的客户custom.myCustomer,潜在客户custom.devCustomer,全部客户custom.allCustomer的缓存
        "custom" : []
    };

    // model对象
    var model = {};
    model.dataStore = dataStore;

    // 更新所有引用用到staffId的地方
    model.updateStaffId = function (staffId) {
        dataStore.staffId = staffId;
    };

    // 更新所有引用用到userId的地方
    model.updateUserId = function (userId) {
        dataStore.userId = userId;
    };


    // 清除缓存
    model.clear = function () {
        $.each(dataStore, function (key) {
            if(key === "staffId"){
                dataStore[key] = ""
            }else if(key === "custom"){
                dataStore[key] = [];
            }else{
                dataStore[key] = {};
            }
        });
    };

    // 获取/设置cache
    model.cache = function (key, value) {
        //argumengts对输入的参数进行跟踪
        var len = arguments.length;
        if (len === 1) {
            return dataStore.myCache[key];
        } else if (len === 2) {
            dataStore.myCache[key] = value;
        }
    };

    // 删除cache
    model.removeCache = function (key) {
        if (dataStore.myCache[key] !== undefined) {
            delete dataStore.myCache[key];
        }
    };

    // 通过key查找dataStore中的value
    // key可以是多级的(如 [key1,key2,key3])
    // 不存在返回null
    model.getData = function (keyArr) {
        var obj = dataStore;
        var i = 0;
        var len = keyArr.length;
        // 循环检测key对应的value是否存在
        for (; i < len; i++) {
            obj = obj[keyArr[i]];
            if (obj === undefined || obj === null || $.isEmptyObject(obj)
                || ($.isArray(obj) && obj.length === 0)) {
                return null;
            }
        }
        return obj;
    };


    // 引入全局变量privateSpaceMKT
    // 需要注意在声明其他全局变量，或是引入其他插件时，要避免引入与此同名的全局变量
    window.privateSpaceMKT = {
        "model": model
    };
});