define("financial/scripts/model/myUtils.js", function (require, exports, module) {
    var service = require("investService");
    var endecryptUtils = $.endecryptUtils;
    var global = $.config.global;
    var model = window.privateSpaceMKT.model;
    var HIscroll = require("hIscroll");
    require("echarts");
    var myUtils = {
    };

    // input获取焦点弹出键盘时，底部栏被顶起的问题
    myUtils.dealPageStyle = function ($page) {
        var bodyHeight = $("body").height();
        var handle;

        // ios的键盘是覆盖在webview上，只有android的是将webview顶上去的
        // 所以只有Android的需要处理样式，ios的不需要
        // platform    "0": pc或手机浏览器; "1": android;  "2" :ios
        if ($.config.platform === "1") {
            $page.find("input,textarea").focus(function () {
                var $this = $(this);
                $page.css("height", bodyHeight);
                $page.find("footer").hide();

                if (!handle) {
                    // 检查键盘是否已收起
                    handle = setInterval(function () {
                        var currBodyHeight = $("body").height();
                        // 根据高度判断键盘是否已收起
                        // 因为Android有虚拟导航栏(荣耀6plus占总高度的7.8%)，由于不清楚所有机型的占比
                        // 所以下面的比较系数暂定为0.85
                        if (currBodyHeight > bodyHeight*0.85) {
                            $page.css("height", "100%");
                            $page.find("footer").show();

                            window.clearInterval(handle);
                            handle = null;

                            //dom.trigger("blur");
                        }
                    }, 300);
                }
            });
        }
    };

    /**
     * 横向切换自动居中
     * curDom :当前选中标签
     * scrollDom :滑动控制标签
     */
    myUtils.scrollLeftAuto = function(curDom,scrollDom){
    	var bwidth = document.body.clientWidth ;             //屏幕宽度
    	var zwidth = parseInt(curDom.css("width"));          //标签自身宽度
    	var lwidth = parseInt(curDom.offset().left);         //标签距离屏幕左边界距离
    	var lleft = lwidth - parseInt((bwidth - zwidth)/2);  //需向左滑动距离
    	var sleft = scrollDom.scrollLeft();                  //当前本身scrollLeft距离
    	scrollDom.animate({ scrollLeft: sleft+lleft }, 200);
    };
    
    // 修改图片的尺寸，使其高度为(bodyHeight * 0.298),宽度等比例缩小或放大
    myUtils.modifySizeOfImg = function (imgDom) {
        var $bodyDom = $("body");
        var bodyWidth = $bodyDom.width();
        var bodyHeight = $bodyDom.height();

        var imgWidth;
        var imgHeight = bodyHeight * 0.298;
        var imgMaxWidth = bodyWidth * 0.925;

        // 此条件判断已经排除了naturalHeight为0的可能性
        if (imgDom && imgDom.naturalHeight) {
            imgWidth = (imgDom.naturalWidth / imgDom.naturalHeight) * imgHeight;
            imgWidth = imgWidth > imgMaxWidth ? imgMaxWidth : imgWidth;
            $(imgDom).css({
                "width": imgWidth,
                "height": imgHeight
            });
        }
    };

    // 切换元素的显示状态，显现时就隐藏，隐藏时显现
    myUtils.toggleDisplay = function ($dom, speed) {
        $dom[$dom.is(":visible") ? "hide" : "show"](speed);
    };

    // 根据key(keyStr)生成一个类map的object
    myUtils.createMap = function (keyStr, arr) {
        var i = 0;
        var len = arr.length;
        var dataMap = {};
        var item;
        for (; i < len; i++) {
            item = arr[i];
            dataMap[item[keyStr]] = item;
        }
        return dataMap;
    };

    // 提示信息
    myUtils.toast = function (tipInfo, showTime, callback) {
        if (typeof showTime === "function") {
            callback = showTime;
            showTime = 1500;
        } else {
            showTime = showTime || 1500;
        }

        var htmlStr = "<p class='psd_txt'>" + tipInfo + "</p>";
        var $dom = $(htmlStr).appendTo("body");
        setTimeout(function () {
            $dom.remove();
            if (callback) callback();
        }, showTime);
    };

    // 混淆手机号(即用*替换中间四个数字)
    myUtils.confuseMobile = function (mobileNo) {
        return mobileNo.replace(/^(\d{3})\d{4}/, "$1****");
    };
    
    // 混淆身份证号(即用*替换中间的数字)
    myUtils.confuseCodeId = function (codeId) {
        return codeId.replace(/^(\d{6})\d{8}/, "$1********");
    };

    // 格式化手机号
    myUtils.formatMobile = function (mobileNo, spt) {
        spt = spt || " ";
        return mobileNo.replace(/^(\d{3})(\d{4})(\d{4})$/, ["$1", "$2", "$3"].join(spt));
    };

    // 在字符串的指定位置插入一个字串
    myUtils.insertSubStr = function (srcStr, subStr, index) {
        //var pattern = new RegExp("^((?:.|\\n){" + index + "})((?:.|\\n)*)$");
        //return srcStr.replace(pattern, ["$1", "$2"].join(subStr));
        return srcStr.slice(0, index) + subStr + srcStr.slice(index);
    };

    // 获取尺寸位置的大小值
    myUtils.getSizeStyleObj = function ($dom, nameArr) {
        var obj = $dom.css(nameArr);
        var name;
        for (name in obj) {
            if (obj.hasOwnProperty(name)) {
                obj[name] = parseFloat(obj[name]);
            }
        }
        return obj;
    };

    // 获取所有的margin值
    myUtils.getMarginObj = function ($dom) {
        return myUtils.getSizeStyleObj($dom, ["margin-top", "margin-bottom", "margin-left", "margin-right"]);
    };

    // 长按事件
    myUtils.bindLongTouchEvent = function ( $dom, callback) {
        var saveTime;
        $dom.bind("touchstart", function (e) {
            saveTime = setTimeout(function () {
                if (callback) callback();
                e.stopPropagation();
            }, 1000);                        
        });
     
        $dom.bind("touchend", function (e) {
            clearTimeout(saveTime);
            e.stopPropagation();
        });
    };

    // 绑定滑动事件
    myUtils.bindSwipeEvent = function ($dom) {
        var startX;
        var startY;

        $dom.bind("touchstart", touchstart);

        function touchstart(event) {
            var touches = event.originalEvent.touches;
            if (touches && touches.length) {
                startX = touches[0].pageX;
                startY = touches[0].pageY;
            }
            $dom.bind("touchmove", touchmove);
            $dom.bind("touchend", touchend);
            event.preventDefault();
        }

        function touchmove(event) {
            var touches = event.originalEvent.touches;
            if (touches && touches.length) {
                var deltaX = startX - touches[0].pageX;
                var deltaY = startY - touches[0].pageY;

                if (deltaX >= 50) {
                    $(this).trigger("swipeLeft");
                }
                if (deltaX <= -50) {
                    $(this).trigger("swipeRight");
                }
                if (deltaY >= 50) {
                    $(this).trigger("swipeUp");
                }
                if (deltaY <= -50) {
                    $(this).trigger("swipeDown");
                }
                if (Math.abs(deltaX) >= 50 || Math.abs(deltaY) >= 50) {
                    $dom.unbind('touchmove', touchmove);
                    $dom.unbind('touchend', touchend);
                }
            }
            event.preventDefault();
        }

        function touchend(event) {
            $dom.unbind('touchmove', touchmove);
            $dom.unbind('touchend', touchend);
            event.preventDefault();
        }
    };
    
    // 滑动搜索
    //参数的含义 $letterBox包裹字符的盒子，$dataBox是我们要查找的文字的内容，$tipBox是滚动到那个英文字母出现提示这个英文字母，
    //$chillData是$databox的子元素,$marginTop是滚动的页面距离顶部的距离
    myUtils.swipeToSearch = function ($letterBox, $dataBox, $tipBox, $childData, $conSwipe, $marginTop) {
        // 阻止冒泡
        $letterBox.bind("click mousedown", function (e) {
            e.stopPropagation();
        });

        var $allLiDom = $letterBox.find("li");
        if ($allLiDom.length === 0) return false;

        var $showLetterDom = $tipBox.find("span");  // 提示框中显示字母的标签
        var charNum = 27;                 // 字符的总个数
        var startLiIndex = 0;
        var startY;                       // 第一个li dom的top值(字母列表)
        var liHeight;                     // 每个li的高度
        var lastLetter;
        var $lastLiDom;
        var $allDataDom;                  // 所有显示数据的dom

        $letterBox.bind("touchstart", function (e) {
            $letterBox.addClass("hover_class");
            // 下面两个值需要等相应的dom显示时才能获取
            liHeight = $allLiDom.eq(0).height();
            startY = $allLiDom.eq(startLiIndex).offset().top;
            // 因为数据的填充是一个异步的过程，所以$allDataDom只能在这里获取
            $allDataDom = $allDataDom || $dataBox.find($childData);

            $letterBox.bind("touchmove", (function () {
                // 降低touchmove事件响应的频率(100ms响应一次)
                var lastTime = 0;
                return function (e) {
                    var currTime = +(new Date);
                    if (currTime - lastTime >= 100) {
                        touchmove(e);
                        lastTime = currTime;
                    }
                };
            })());
            $letterBox.bind("touchend", touchend);
            e.preventDefault();
        });

        function touchmove(e) {
            var disY;
            var currLiIndex;
            var $currLiDom;
            var currLetter;
            var searchDom;
            var searchDomTop;
            var firstDomTop;                  // 数据列表的第一个dom的top
            var touches = e.originalEvent.touches;
            if (touches && touches.length > 0) {
                disY = touches[0].pageY - startY;
                currLiIndex = Math.floor(startLiIndex + (disY / liHeight));
                // 处理序号上越界和下越界的情况
                currLiIndex = currLiIndex > (charNum - 1) ? (charNum - 1) :
                    (currLiIndex < 0 ? 0 : currLiIndex);
                $currLiDom = $allLiDom.eq(currLiIndex);
                currLetter = $currLiDom.find("a").text();
                // 让同一个字符只操作一次
                if (currLetter !== lastLetter) {
                    // 字母列表和提示框的处理
                    $showLetterDom.text(currLetter);
                    if ($tipBox.is(":hidden")) $tipBox.show();
                    $lastLiDom && $lastLiDom.removeClass("swipe_over");
                    $currLiDom.addClass("swipe_over");

                    // 根据触摸到的字母，将相应的分类区块滑动到顶部
                    searchDom = $allDataDom.filter("[data-letter='" + currLetter + "']");
                    if (searchDom.length > 0) {
                        firstDomTop = $allDataDom.eq(0).offset().top-$marginTop;
                        searchDomTop = searchDom.offset().top;
                        $conSwipe.animate({
                            "scrollTop": searchDomTop - firstDomTop
                        }, "fast");
                    }

                    // 保存上一次触摸的字母和相应的li dom
                    lastLetter = currLetter;
                    $lastLiDom = $currLiDom;
                }
            }
            e.preventDefault();
        }

        function touchend(e) {
            $letterBox.unbind("touchmove");
            $letterBox.unbind("touchend");
            // 清理工作
            $tipBox.hide();
            $letterBox.removeClass("hover_class");
            $lastLiDom && $lastLiDom.removeClass("swipe_over");
            $lastLiDom = lastLetter = null;
            e.preventDefault();
        }
    };

    // 对参数进行安全校验、防止xss攻击
    myUtils.checkParam = function (paramArr) {
        var i = 0;
        var len = paramArr.length;
        var patt = /<|>/;
        var obj;
        for (; i < len; i++) {
            obj = paramArr[i];
            if (patt.test(obj.param)) {
                $.toast(obj.paramName + "中存在非法字符：'<' 或 '>'");
                return false;
            }
        }
        return true;
    };

    // 根据keyArr创建一个相应的domArr
    myUtils.getDomArr = function (domKeyArr, jQueryMap) {
        var domArr = [];
        var i = 0;
        var len = domKeyArr.length;
        for (; i < len; i++) {
            domArr[i] = jQueryMap[domKeyArr[i]];
        }
        return domArr;
    };

    // 是否不是数字和字母的组合
    myUtils.isNotNumberAndChar = function (str) {
        return /\W+/.test(str) || !/\d/.test(str) || !/[A-Za-z]/.test(str);
    };

    // 是否高亮显示按钮
    myUtils.changeBtnStatus = function ($btnDom, isHighlight) {
        if (typeof isHighlight === "function") {
            isHighlight = isHighlight();
        }

        var funcName = isHighlight ? "removeClass" : "addClass";
        $btnDom[funcName]("disabled");
    };

    // 判断是否存在空的input输入框
    myUtils.hasEmptyInput = function (inputArr) {
        var valArr = myUtils.trimInput(inputArr);
        var i = 0;
        var len = valArr.length;
        for (; i < len; i++) {
            if (!valArr[i]) {
                return true;
            }
        }
        return false;
    };

    // 在input框中，不允许输入头部或尾部存在空格的字符串
    // 同时返回trim后的val
    myUtils.trimInput = function (inputArr) {
        var i = 0;
        var len;
        var oldVal;
        var val;
        var valArr = [];
        inputArr = $.isArray(inputArr) ? inputArr : [inputArr];

        for (len = inputArr.length; i < len; i++) {
            oldVal = inputArr[i].val();
            val = oldVal.trim();
            valArr[i] = val;
            if (val !== oldVal) {
                inputArr[i].val(val);
            }
        }

        return valArr;
    };

    // 让input输入框获取焦点时，就隐藏提示信息
    myUtils.dealInputTip = function ($inputDom) {
        var tipMap = {};
        $inputDom.focus(function () {
            var $this = $(this);
            var tipStr = $this.attr("placeholder");
            var id = $this.attr("id");
            tipMap[id] = tipStr;
            $this.attr("placeholder", "");
        }).blur(function () {
            var $this = $(this);
            var id = $this.attr("id");
            $this.attr("placeholder", tipMap[id]);
        });
    };

    // 回退多次
    myUtils.pageBack = function (num) {
        var time = 100;
        var doneNum = 0;
        var $dom;
        var func;
        if (typeof num === "number") {
            // 当回退次数超过3时，才进行特殊处理
            if (num > 3) {
                $dom = $("body #afui").hide();
                func = function () {
                    $.pageBack();
                    if ((doneNum += 1) === num) {
                        $dom.show();
                    }
                };
            } else {
                func = function () {
                    $.pageBack();
                };
            }
            // 除了用函数模拟块级作用域之外,不要在循环中定义函数
            // 因为这样将多次（循环的次数）创建函数对象，代码效率不高
            for (var i = 0; i < num; i++) {
                setTimeout(func, i * time);
            }
        }
    };

    // 初始化时给不同的prePageCode配置不同的处理逻辑
    myUtils.switchProcess = function (param) {
        var prePageCode = $.getSStorageInfo("_prePageCode");
        var processMap = param.processMap;
        var pageStr;
        var func;
        var flag;
        // 在switch逻辑之前执行
        if (param.before && (param.before(prePageCode) === false)) return false;
        // 在switch逻辑
        if (processMap) {
            for (pageStr in processMap) {
                flag = false;
                if (processMap.hasOwnProperty(pageStr) && (func = processMap[pageStr])) {
                    // 判读有没取非的标识"^"
                    if (pageStr[0] === "^") {
                        flag = pageStr.slice(1).split("|").indexOf(prePageCode) === -1;
                    } else {
                        flag = pageStr.split("|").indexOf(prePageCode) > -1;
                    }

                    flag && func(prePageCode);
                }
            }
        }
        // 在switch逻辑之后执行
        param.after && param.after(prePageCode);
    };

    // 功能:判断是否为6位数字强密码
    // 参数 strValue : 需要检验的密码字符串
    //      filter  ：要过滤数组,数组中的每一项都不能包含当前的密码串，否则认为密码为弱密码，比如可以用身份证，手机等校验
    myUtils.isStrongPwd = function (strValue, filters) {
        var i;
        var c;
        var filter;
        var str;
        var temp = "";
        var map = {};

        // 不是6位数字
        if (!/^\d{6}$/.test(strValue)) return false;

        // 3个一样
        if (/([\d])\1{2}/.test(strValue)) return false;

        // 顺增
        str = strValue.replace(/\d/g, function ($0, pos) {
            return parseInt($0) - pos;
        });
        if (/^(\d)\1+$/.test(str)) return false;

        // 顺减
        str = strValue.replace(/\d/g, function ($0, pos) {
            return parseInt($0) + pos;
        });
        if (/^(\d)\1+$/.test(str)) return false;

        // 六个数字中至少有三个不同
        for (i = 0; i < strValue.length; i++) {
            c = strValue.charAt(i);
            if (temp.indexOf(c) == -1) {
                temp += c;
            }
        }
        if (temp.length <= 2) return false;

        // 相同数字出现次数不能超过2次
        for (i = 0; i < strValue.length; i++) {
            c = strValue.charAt(i);
            if (!map[c]) {
                map[c] = 0;
            }
            map[c] = (map[c] + 1);
            if (map[c] >= (strValue.length / 2)) {
                return false;
            }
        }

        // 过滤一些特有的密码
        if (filters && filters.length > 0) {
            for (i = 0; i < filters.length; i++) {
                filter = filters[i];
                if (filter.indexOf(strValue) > -1) {
                    return false;
                }
            }
        }

        return true;
    };

    // 加密
    myUtils.doRSA = function (paramMap, callback) {
        service.getRSAKey({}, function (results) {
            var result = results[0];
            var modulus = result.modulus;
            var publicExponent = result.publicExponent;
            var key;
            for (key in paramMap) {
                if (paramMap.hasOwnProperty(key)) {
                    paramMap[key] = endecryptUtils.rsaEncrypt(modulus, publicExponent, paramMap[key]);
                }
            }

            if (callback) callback(paramMap);

        }, null, {"isLastReq": false});
    };

    // 登录
    // (rsaParam\loginParam) :{merStaffId|mobileNo, pwd}
    // isCache 是否缓存数据
    myUtils.login = function (paramMap) {
        var rsaParam = paramMap.rsaParam;       // rsaParam密码已加密
        var loginParam = paramMap.loginParam;   // loginParam密码未加密
        var isCache = paramMap.isCache;         // 是否缓存数据
        var successFunc = paramMap.successFunc;
        var errorFunc = paramMap.errorFunc;

        if (rsaParam) {
            toLogin(rsaParam, successFunc, errorFunc, isCache);
        } else if (loginParam) {
            // 对登陆密码进行RSA加密
            myUtils.doRSA({"pwd": loginParam.loginPwd}, function (rsaMap) {
                loginParam.loginPwd = rsaMap.pwd;
                toLogin(loginParam, successFunc, errorFunc, isCache);
            });
        }
    };

    // 调登录接口
    function toLogin(loginParam, successFunc, errorFunc, isCache) {
        // 调用登陆接口进行登陆操作
        service.login(loginParam, function (data) {
            var result = data[0];

            if (isCache === true) {
                cacheData(loginParam, result);
            }

            // 执行成功回调函数
            if (successFunc){
                $.callMessage({
                    "funcNo": "70006",
                    "userName": result.employeeNo,
                    "password": $.getLStorageInfo("loginPwd")

                });
                //存登录信息给壳子与IM同步登录
                $.callMessage({
                    "funcNo"   : "80101",
                    "mobileNo" : result.idCode,
                    //"mobileNo" : result.employeeNo,
                    "loginPwd" : $.getLStorageInfo("loginPwd")
                });

                ////同步信息到im
                //$.callMessage({
                //    "funcNo"      : "80111",
                //    "username"    : result.employeeNo,
                //    "nickname"    : $.getSStorageInfo("staffName"),
                //    "thumbpic"    : $.getSStorageInfo("photoPath"),
                //    "originalpic" : $.getSStorageInfo("photoPath")
                //});
                //

                var postNo = result.postNo;
                $.setSStorageInfo("postNo",postNo);
                $.setSStorageInfo("postType",result.orderType);
                //员工
                if( postNo == "wealthManager" || postNo == "customerManager" ||  postNo == "investAdviser" ||  postNo == "others"){
                    $.setSStorageInfo("role","1");
                }else if( postNo == "branchManager" ||  postNo == "mktManager" || postNo == "areaManager" ||  postNo == "ivtManager"){
                    //管理员
                    $.setSStorageInfo("role","0");
                }
                //判断是否多角色
                service.staffRoleInfo({
                    "actionType" : "1",
                    "userId" : $.getSStorageInfo("userId")
                }, function (results) {
                    //1是总监 0是经理
                    if(results.length>1){
                        $.setSStorageInfo("mainRole", "1");
                    }else{
                        $.setSStorageInfo("mainRole", "0");
                    }

                });
                //判断是否多账号
                service.staffRoleInfo({
                    "actionType" : "2",
                    "userId" : $.getSStorageInfo("userId")
                }, function (results) {
                    //1是多账号 0 是一个账号
                    if(results.length>1){
                        $.setSStorageInfo("accountMoer", "1");
                    }else{
                        $.setSStorageInfo("accountMoer", "0");
                    }

                });
                //获取客户岗位信息
                service.staffPosInfo({
                    "user_code" : $.getSStorageInfo("employeeNo")
                }, function (results) {
                    if(results.length>0){
                        $.setSStorageInfo("postIdChannel", results[0].post_id);
                        $.setSStorageInfo("postNameChannel", results[0].post_name);
                    }

                });

                successFunc(result);
            }
        }, function (error_no, error_info) {
            if (errorFunc) {
                // 执行失败回调函数
                errorFunc(error_no, error_info);
            } else {
                $.alert(error_info);
            }
        });
    }

    // 缓存返回的数据
    function cacheData(loginParam, result) {
        // 在session中缓存返回的数据
        $.each(result, function (index, item) {

            if (index === "photoPath" && item) {
                // 保存图像的原始地址（服务器端的地址）
                $.setSStorageInfo("photoUrl", item);

                var strIndex = item.indexOf("upload");
                item = global.serverAddr + item.substring(strIndex);
            }
            if (index === "employeeNo" && item) {
                // 保存图像的原始地址（服务器端的地址）
                sessionStorage.setItem("employeeNo", item);

//                var strIndex = item.indexOf("upload");
//                item = global.serverAddr + item.substring(strIndex);
            }
            $.setSStorageInfo(index, item);
        });

        // 保存登录状态
        $.setSStorageInfo("isLogin", "true");
        
        $.setLStorageInfo("staffId", result.staffId);
        // 更新缓存中的staffId的值
        model.dataStore.staffId = result.staffId;
        model.updateStaffId(result.staffId);

        model.dataStore.userId = result.staffId;
        model.updateUserId(result.staffId);

        // 存储账户的staffId和加密后的密码
        $.setLStorageInfo("mobileNo", result.mobileNo);
        $.setLStorageInfo("loginPwd", loginParam.loginPwd);

        //用浏览器存缓存的话，部分手机的浏览器有可能被手机厂商的设置导致登录问题
        //所有当在手机使用的时候，用壳子来存缓存
        //保存数据用户缓存,用缓存存手机号码
        $.callMessage({
            "funcNo": "50042",
            "key"   : "mobileNo",
            "value" : result.mobileNo,
        });
        //保存数据用户缓存,用缓存存密码
        $.callMessage({
            "funcNo": "50042",
            "key"   : "loginPwd",
            "value" : loginParam.loginPwd,
        });


    }

    // 获取二维码
    myUtils.getQRcode = function (param, callback) {
        var qrBase64 = model.getData(["qrBase64Map", param.guideSerial]);
        // 检测是否已缓存对应的二维码数据
        if (qrBase64) {
            if (callback) callback(qrBase64);
        } else {
            // 重新生成二维码
            updateQRCode(param, callback);
        }
    };

    // 重新生成二维码
    function updateQRCode(param, callback) {
        var photoUrl = $.getSStorageInfo("photoUrl");
        var qrBase64;

        service.getBase64OfPhoto({
            "photoUrl": photoUrl,
            // 将“&”字符替换成“,”;服务器端会替换回来的
            "content": param.text.replace(/&/g, ",")
        }, function (results) {
            qrBase64 = results[0].base64Str;
            if (!qrBase64) {
                $.alert("二维码不存在！")
            }

            if (callback) {
                callback(qrBase64);
                model.dataStore.qrBase64Map[param.guideSerial] = qrBase64;
            }
        }, function (error_no, error_info) {
            $.alert(error_info);
        });

        //var handle = setInterval(function () {
        //    if (flag === 1) {
        //        window.clearInterval(handle);
        //
        //        if (callback) {
        //            callback(qrBase64);
        //            model.dataStore.qrBase64Map[param.guideSerial] = qrBase64;
        //        }
        //    }
        //}, 50);
    }

    // 生成二维码
    //function createQRcode(param) {
    //    var $canvasBody = $("<div></div>");
    //    var $canvas = $canvasBody.qrcode({
    //        "render" : "canvas",
    //        "ecLevel": "M",
    //        "text"   : param.text,
    //        "size"   : 400,
    //        "mode"   : 4,
    //        "mSize"  : 0.18,
    //        "image"  : param.image
    //    }).find("canvas");
    //
    //    // 将canvas的内容转换为base64数据
    //    return $canvas[0].toDataURL("image/*", 0.8);
    //}

    // 将姓名进行字母排序
    myUtils.sortLetter = function ($results, callback) {
        var letterArr;
        var branchMap = {};
        var resLetter = {};
        if ($results.length > 0) {
            $.each($results, function (index, item) {
                // letterCode为26个大写字母或则空串"";
                var firstCode = item.firstCode || item.letterCode;
                var letter = firstCode || "#";
                (branchMap[letter] = branchMap[letter] || []).push(item);
            });
        }
        letterArr = Object.keys(branchMap).sort(function (a, b) {
            if (a === "#") return 1;
            if (b === "#") return -1;
            if (a < b) return -1;
            if (a === b) return 0;
            if (a > b) return 1;
        });
        resLetter = {"branchMap": branchMap, "letterArr": letterArr};
        if(callback) callback(resLetter);
    };

    // 切换弹出层的显示状态
    // layerArea:弹出层汇总  type: hide:隐藏  show：显示(为show时必须传$showDom)
    myUtils.toggleLayerArea = function (layerArea, type, $showDom) {
        // 隐藏所有弹框层
        $.each(layerArea, function (key, $thisDom) {
            if ($thisDom.is(":visible")) {
                $thisDom.find(">div").slideUp("fast");
                $thisDom.fadeOut("fast");
            }
        });

        if (type === "show") {
            $showDom.show();
            $showDom.find(">div").slideDown("fast");
        }
    };

    // 格式化手机号
    myUtils.Format = function(fmt)
    {
        var o = {
            "M+" : this.getMonth()+1,                 //月份
            "d+" : this.getDate(),                    //日
            "h+" : this.getHours(),                   //小时
            "m+" : this.getMinutes(),                 //分
            "s+" : this.getSeconds(),                 //秒
            "q+" : Math.floor((this.getMonth()+3)/3), //季度
            "S"  : this.getMilliseconds()             //毫秒
        };
        if(/(y+)/.test(fmt))
            fmt=fmt.replace(RegExp.$1, (this.getFullYear()+"").substr(4 - RegExp.$1.length));
        for(var k in o)
            if(new RegExp("("+ k +")").test(fmt))
                fmt = fmt.replace(RegExp.$1, (RegExp.$1.length==1) ? (o[k]) : (("00"+ o[k]).substr((""+ o[k]).length)));
        return fmt;
    };

    // 滑出/收起筛选页面
    myUtils.moveTo = function(type1, callback, filterWrapper, filterSlideBar){
        var speed = 350;
        var outCssObj = {
            "transform" : "translate3d(3.8rem,0,0)",
            "transition": "all " + speed + "ms"
        };
        var inCssObj = {
            "transform" : "translate3d(0,0,0)",
            "transition": "all " + speed + "ms"
        };

        if (type1 === "in") {
            filterWrapper.show();
            // 获取高度，让浏览器立即渲染上面设置的样式;
            filterWrapper.height();
            filterSlideBar.show();
            filterSlideBar.css(inCssObj);
        } else {
            filterSlideBar.css(outCssObj);
            filterWrapper.hide();
            setTimeout(function () {
                if (callback) callback();
                filterSlideBar.hide();
            }, speed * 0.5);
        }
    };

    myUtils.initHIscroll = function(myHIscroll,wrapper,scroller,lab,dotBox,flag) {
        if(myHIscroll){
            myHIscroll.destroy();
            myHIscroll = null;
        }
        if(!myHIscroll) {
            var config = {
                "wrapper": wrapper,
                "scroller": scroller,
                "perCount": 1,      // 每个可视区域显示的子元素，就是每个滑块区域显示几个子元素，必传
                "showTab": false,  // 是否有导航点
                "auto": flag,   // 是否自动播放，非必传，默认为false
                "interval": 3000,
                "mouseWheel": true,
                "click": true,
                "preventDefault" :false,
                "onScrollEnd": function () {

                        dotBox.find("span").eq(myHIscroll.getActivePage()).addClass("act")
                        .siblings().removeClass("act");
                    //scroller.attr("transform")
                }
            };

            try {
                myHIscroll = new HIscroll(config);
                scroller.find(lab).show();
            } catch (e) {
            }
        }
    };


    /****
     * 隐藏系统底部TabBar
     * moduleName  的模块名
     * flag 0 隐藏 1显示
     * role 0管理员 1 普通员工
     */
    myUtils.hideBtn = function() {
        $.callMessage({
            "funcNo"         : "80108",
            "moduleName"     : "",
            "fromModuleName" : "mall",
            "flag"           : "0",
            "role"           : ""
        });
    };

    myUtils.showBtn = function(modeleName,role) {
        //显示系统底部TabBar
        $.callMessage({
            "funcNo"         : "80108",
            "moduleName"     : modeleName,
            "fromModuleName" : "mall",
            "flag"           : "1",
            "role"           : role
        });

    };

    myUtils.showLayer1 = function($page){
        $page.find(".page_box").css("opacity","0");
        $page.find(".page_boxLoad").show();
        //$page.find(".page_boxLoad").hide();
    };
   myUtils.hideLayer1 = function($page){
        $page.find(".page_box").css({"opacity":"1"});
       $page.find(".page_boxLoad").hide();
        //$page.find("article .page_box").show();
    };


    myUtils.showLayer = function($page){
        $page.find(".page_box").hide();
        $page.find(".page_boxLoad").show();
    };
    myUtils.hideLayer = function($page){
        $page.find(".page_box").show();
        $page.find(".page_boxLoad").hide();
    };

    myUtils.addLayer = function($page){
        //$page.find(".page_box").css("opacity","0");
        //$page.find(".page_box").css("display","none");
        $page.find("article").append('<div class="page_boxLoad load_box" ><div class="load_con"><span class="load_pic"></span><p>正在加载...</p></div></div>');
    };
    myUtils.cancelLayer = function($page){
        //遮罩层去掉
        //$page.find(".page_box").css("display","block");
        $page.find("article .load_box").remove();
        //$page.find("article .page_box").show();
    };

    //标题上面的加载转圈
    myUtils.loadService = function($page){
        $page.find(".loadService").show();
    };
    myUtils.hideLoadService = function($page){
        //遮罩层去掉
        $page.find(".loadService").hide();
    };


    //获取最近三个月时间的接口，多页面公用
    myUtils.insertMonth = function(curMonth,perMonth,beforPreMonth){
        service.getThereMonth({}, function(result){
            var peryear = result[0].perMonth.substr(0,4);
            var permonth = result[0].perMonth.substr(5);
            var beforPreyear = result[0].beforPreMonth.substr(0,4);
            var beforPremonth = result[0].beforPreMonth.substr(5);

            curMonth.attr("data-month",result[0].curMonth);
            perMonth.attr("data-month",result[0].perMonth);
            beforPreMonth.attr("data-month",result[0].beforPreMonth);

            curMonth.html("本月");
            perMonth.html(peryear+"年"+permonth+"月");
            beforPreMonth.html(beforPreyear+"年"+beforPremonth+"月");
        });
    };

    //折线图的绘图
    myUtils.totalAssetChart = function(custChanChart, dateStrArray, name, dayCustomerCount) {
        // 设置曲线图父元素的固定高度
//        custChanChart.css({
//            "height": $(this).width() * 0.60,
//            "width" : $(this).width(),
//            "display": "block"
//        });
        custChanChart.highcharts({
            chart      : {
                type           : 'line',
                spacing        : [20, 20, 10, 10],
                backgroundColor: '#fff'
            },
            title      : {
                text: ''
            },
            credits    : {
                enabled: false
            },
            xAxis      : {
                categories : dateStrArray

            },
            yAxis      : {
                title            : {
                    enabled: false
                }
                //labels           : {
                //    style: {
                //        color: '#333'//颜色
                //    }
                //}
            },
            tooltip    : {
                formatter:function(){
                    return "总资产："+this.y+"<br/>日期："+dateStrArray[this.x]
                }
            },
            series     : [{
                name : name,
                data : dayCustomerCount

            }]

        });
        //custChanChart.highcharts({
        //    chart      : {
        //        type           : 'line',
        //        spacing        : [10, 20, 5, 0],
        //        backgroundColor: '#fff'
        //    },
        //    title      : {
        //        text: ''
        //    },
        //    credits    : {
        //        enabled: false
        //    },
        //    //exporting  : {
        //    //    enabled: false
        //    //},
        //    //legend     : {
        //    //    enabled: false
        //    //},
        //    xAxis      : {
        //        tickmarkPlacement: 'on',
        //        gridLineWidth    : 0.5,
        //        gridLineColor    : "#333",
        //        labels           : {
        //            formatter: function () {
        //                var data = dateStrArray[this.value];//.substr(5,10);
        //                return data;
        //            },
        //            //step :30,
        //            style    : {
        //                color: '#333'//颜色
        //            }
        //        },
        //        tickInterval     :30
        //    },
        //    yAxis      : {
        //        title            : {
        //            enabled: false
        //        },
        //        labels           : {
        //            style: {
        //                color: '#333'//颜色
        //            }
        //        }
        //    },
        //    tooltip    : {
        //        formatter:function(){
        //            return "总资产："+this.y+"<br/>日期："+dateStrArray[this.x]
        //        }
        //    },
        //    series     : [{
        //        name : name,
        //        data : dayCustomerCount
        //
        //    }]
        //
        //});
    }
    
    //echart画图公用方法
    //echart画图公用方法
    myUtils.echartPaint =function generateDraw(JQueydom,x,y,type,yName,wState){
        var myChart = echarts.init(JQueydom.get(0));
        option = {
            title : {
                text: '' ,
            },
            tooltip : {
                show: true,
                trigger   : 'axis',
                padding   : 5,
                formatter : function(params) {
                    var res = params[0].name + "<br/> 值: "+(wState =="万元" ?(Math.abs(params[0].data) > 1 ? params[0].data.toFixed(2)+"万元" :(params[0].data*10000)+"元")
                    		:(wState =="元" ? params[0].data +"元" : params[0].data +"人" ));
                    return res;
                }
            },
            toolbox: {
                show : true,
                feature : {
                    mark : {show: true,},
                    dataView : {show: true, readOnly: false,},
                    magicType : {show: true, type: ['line', 'bar'],},
                    restore : {show: true,},
                    saveAsImage : {show: true,},
                },
            },
            grid  : {
                     x  : 70,
                     y  : 40,
                     x2 : 40,
                     y2 : 30
                },
            calculable : true,
            xAxis : [
                {
                    type : 'category',
                    data : x,           //x轴数据
                    boundaryGap : true,
                },
            ],
            yAxis : [
                {
                    type : 'value',
                    show : true,
                    scale : true,
                    name : yName+(wState == "人" ? "" : "("+wState+")")
                }
            ],
            series : [
                {
                    type:type,	 //图形类型
                    barWidth: 20,//固定柱子宽度
                    itemStyle: {
                        //normal: {
                        //    label : {
                        //        show: true,
                        //        position: 'top'
                        //    }
                        //}
                    },
                    data:y,    //y轴数据
                },
            ]
        };
        myChart.setOption(option);
    };

    // 绑定滑动事件
    myUtils.bindSwipeList = function ($dom, $content) {
        var startX;
        var startY;
        var curX;
        var maxWidth;
        var fundListHeadEle;
        var startTime;

        $dom.bind("touchstart", touchstart);

        function touchstart(e) {
            var ev = e.originalEvent || e;
            startX = ev.changedTouches[0].clientX;
            startY = ev.changedTouches[0].clientY;
            curX = myUtils.getTransformX(this); // 当前transform X的值
            maxWidth = $dom.find("tr").width() - $dom.width(); // 滚动区域的最大宽度
            fundListHeadEle = $content;
            startTime = new Date().getTime();
            $dom.bind("touchmove", touchmove);
            $dom.bind("touchend", touchend);
            //ev.preventDefault();
        }

        function touchmove(e2) {

            var ev2 = e2.originalEvent || e2;
            var cX = ev2.changedTouches[0].clientX - startX;
            var cY = ev2.changedTouches[0].clientY - startY;
            if (Math.abs(cX) > (2 * Math.abs(cY) + 5)) {
                var changeX = curX + cX; // 需要切换transform x的值
                myUtils.setTouchEndTransform(this, changeX, maxWidth);
                myUtils.setTouchEndTransform(fundListHeadEle[0], changeX, maxWidth);
                ev2.preventDefault();
            }
        }

        function touchend(e3) {
            var ev3 = e3.originalEvent || e3;
            var cX = ev3.changedTouches[0].clientX - startX;
            var cY = ev3.changedTouches[0].clientY - startY;
            var changeX = curX;
            if (Math.abs(cX) > (2 * Math.abs(cY) + 5)) {
                var disTime = 2 * (new Date().getTime() - startTime);
                disTime = disTime > 500 ? 500 : disTime;
                var inertiaLen = (500 - disTime) / 5 + Math.abs(cX);
                inertiaLen = inertiaLen || 10;
                changeX = cX > 0 ? (curX + cX + inertiaLen) : (cX < 0 ? (curX + cX - inertiaLen) : curX);
                myUtils.setTouchEndTransform(this, changeX, maxWidth, disTime);
                myUtils.setTouchEndTransform(fundListHeadEle[0], changeX, maxWidth, disTime);
                //ev3.preventDefault();
            }

            $dom.unbind('touchmove', touchmove);
            $dom.unbind('touchend', touchend);

        }
    };

    /**
     * 获取transform x的值
     */
    myUtils.getTransformX = function(obj){
        var transform = obj.style.transform || obj.style.webkitTransform;
        return myUtils.cusParseFloat(transform.replace(/[^\d\.-]/g, ""));
    };


    /**
     * touchEnd 最后滚动位移设置transform属性
     */
    myUtils.setTouchEndTransform = function(obj, changeX, maxWidth, difTime){
        myUtils.setTransitionStyle("all "+ difTime +"ms ease-out", obj);
        changeX = changeX > 0 ? 0 : (Math.abs(changeX) > maxWidth ? ("-" + maxWidth) : changeX);
        myUtils.setTransformStyle("translateX("+ (changeX) +"px)", obj);
    };

    /**
     * 设置transition样式
     */
    myUtils.setTransitionStyle = function(style, obj){
        obj.style.webkitTransition = style;
        obj.style.transition = style;
    };

    /**
     * 设置transform样式
     */
    myUtils.setTransformStyle = function(style, obj){
        obj.style.webkitTransform = style;
        obj.style.transform = style;
    };

    /**
     * 描述：重写 javascript parseInt 方法
     *
     * @author
     * @param str: 待转换的字符串，
     * @param dftVal: 如果str为空或者parseFloat解析结果为NaN时 返回的默认值 ，不传默认返回0
     * @returns
     */
    myUtils.cusParseFloat = function(str, dftVal){
        dftVal = dftVal || 0;
        var result = dftVal;
        if (str) {
            result = parseFloat(str, 10) || dftVal; // 使用十进制进行转换
        }
        return result;
    };

    /**
     * 列表单位为万统一处理   小于100w保留四位小数点   大于100w保留两位小数点
     */
    myUtils.changeUtil = function(num){
    	var result = 0 ;
    	if(num =="" || num =="0"){
    		result = 0;
    	}else{
    		if(num < 1000000){
        		result = parseFloat((num/10000).toFixed(4));
        		if(result.toString().length - result.toString().indexOf(".") < 2 ){
        			result = (parseFloat(result)).toFixed(2);
        		}
        	}else{
        		result = (parseFloat(num/10000)).toFixed(2);
        	}
    	}
        return result;
    };
    
    /**
     * 资产万元以上数字转换  当资产超过10万元以上，转换为以万元为单位的数字，并保留两位小数，否则不做处理
     */
    myUtils.changeMoney = function(num){
        var state = false;
        result = {} ;
        //判断大于1w
        if(num > 10000 || num < -10000){
            num = (parseFloat(num/10000)).toFixed(2);
            state = true;
        }
        result.num = num ? num :"0";
        result.state = state;
        return result;
    };

    /**
     * 将金钱数字用逗号隔开
     */
    myUtils.splitMoney = function(s, n){
        n = n > 0 && n <= 20 ? n : 2;  
        s = parseFloat((s + "").replace(/[^\d\.-]/g, "")).toFixed(n) + "";  
        var l = s.split(".")[0].split("").reverse(), r = s.split(".")[1];  
        t = "";  
        for (i = 0; i < l.length; i++) {  
            t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");  
        }  
        var result = t.split("").reverse().join("") + "." + r;
        return result;
    };

    //碰撞检测
    myUtils.colTest = function(obj1,obj2){
        var t1 = obj1.offsetTop;
        var r1 = obj1.offsetWidth+obj1.offsetLeft;
        var b1 = obj1.offsetHeight+obj1.offsetTop;
        var l1 = obj1.offsetLeft;

        var t2 = obj2.offsetTop;
        var r2 = obj2.offsetWidth+obj2.offsetLeft;
        var b2 = obj2.offsetHeight+obj2.offsetTop;
        var l2 = obj2.offsetLeft;

        if(t1>b2||r1<l2||b1<t2||l1>r2){
            return false;
        }else{
            return true;
        }
    }
    //勾股定理求距离
    myUtils.getDis = function(obj1,obj2){
        var a = obj1.offsetLeft-obj2.offsetLeft;
        var b = obj1.offsetTop-obj2.offsetTop;
        return Math.sqrt(Math.pow(a,2)+Math.pow(b,2));
    }
    //找到距离最近的
    myUtils.findMin = function(obj,aLi){
        var minDis = 999999999;
        var minIndex = -1;
        for(var i=0;i<aLi.length;i++){
            if(obj==aLi[i])continue;
            if(myUtils.colTest(obj,aLi[i])){
                var dis =  myUtils.getDis(obj,aLi[i]);
                if(dis<minDis){
                    minDis = dis;
                    minIndex = i;
                }
            }
        }
        if(minIndex==-1){
            return null;
        }else{
            return aLi[minIndex];
        }
    }

    //通过class获取元素
    myUtils.getClass = function(cls){
        var ret = [];
        var els = document.getElementsByTagName("*");
        for (var i = 0; i < els.length; i++){
            //判断els[i]中是否存在cls这个className;.indexOf("cls")判断cls存在的下标，如果下标>=0则存在;
            if(els[i].className === cls || els[i].className.indexOf("cls")>=0 || els[i].className.indexOf(" cls")>=0 || els[i].className.indexOf(" cls ")>0){
                ret.push(els[i]);
            }
        }
        return ret;
    }
    myUtils.getStyle = function(obj,attr){//解决JS兼容问题获取正确的属性值
        return obj.currentStyle?obj.currentStyle[attr]:getComputedStyle(obj,false)[attr];
    }
    myUtils.startMove = function(obj,json,fun){
        clearInterval(obj.timer);
        obj.timer = setInterval(function(){
            var isStop = true;
            for(var attr in json){
                var iCur = 0;
                //判断运动的是不是透明度值
                if(attr=="opacity"){
                    iCur = parseInt(parseFloat(myUtils.getStyle(obj,attr))*100);
                }else{
                    iCur = parseInt(myUtils.getStyle(obj,attr));
                }
                var ispeed = (json[attr]-iCur)/8;
                //运动速度如果大于0则向下取整，如果小于0想上取整；
                ispeed = ispeed>0?Math.ceil(ispeed):Math.floor(ispeed);
                //判断所有运动是否全部完成
                if(iCur!=json[attr]){
                    isStop = false;
                }
                //运动开始
                if(attr=="opacity"){
                    obj.style.filter = "alpha:(opacity:"+(json[attr]+ispeed)+")";
                    obj.style.opacity = (json[attr]+ispeed)/100;
                }else{
                    obj.style[attr] = iCur+ispeed+"px";
                }
            }
            //判断是否全部完成
            if(isStop){
                clearInterval(obj.timer);
                if(fun){
                    fun();
                }
            }
        },30);
    }

    //公告滚动
    myUtils.Scroll = function(obj,opt,callback){
    	if(!opt) var opt={};
    	var oo;
    	var _this=obj.eq(0).find("ul:first");
    	var lineH=_this.find("li:first").height(),//23
    	line = opt.line?parseInt(opt.line,10):parseInt(this.height()/lineH,10),
    	speed=opt.speed?parseInt(opt.speed,10):7000, //卷动速度，数值越大，速度越慢（毫秒）
    	timer=opt.timer?parseInt(opt.timer,10):7000; //滚动的时间间隔（毫秒）
    	if(line==0) line=1;
    	var upHeight = 0-line*lineH;//-总高度
	    scrollUp=function(){
		    _this.animate({
		    marginTop:upHeight // <li>的margin-top
		    },speed,function(){
			    for(i=1;i<=line;i++){
			    _this.find("li:first").appendTo(_this);
			    }
		    	_this.css({marginTop:0});
		    	}
		    );
	    };
	    var timerID = function(){
	    	oo =setInterval("scrollUp()",timer);
	    };
	   	timerID();
    _this.hover(function(){
	    clearInterval(oo);
	    },function(){
			timerID();
	    }).mouseout(function(){
	    	$('body').css({'background-color':'#aecdef'});
	    });
    }

    //禁止底部滚动
    myUtils.smartScroll = function(container, selectorScrollable) {
        // 如果没有滚动容器选择器，或者已经绑定了滚动时间，忽略
        if (!selectorScrollable || container.data('isBindScroll')) {
            return;
        }
    
        // 是否是搓浏览器
        // 自己在这里添加判断和筛选
        var isSBBrowser;
    
        var data = {
            posY: 0,
            maxscroll: 0
        };
    
        // 事件处理
        container.on({
            touchstart: function (event) {
                var events = event.touches[0] || event;
                
                // 先求得是不是滚动元素或者滚动元素的子元素
                var elTarget = $(event.target);
                
                if (!elTarget.length) {
                    return;    
                }
                
                var elScroll;
                
                // 获取标记的滚动元素，自身或子元素皆可
                if (elTarget.is(selectorScrollable)) {
                    elScroll = elTarget;
                } else if ((elScroll = elTarget.parents(selectorScrollable)).length == 0) {
                    elScroll = null;
                }
                
                if (!elScroll) {
                    return;
                }
                
                // 当前滚动元素标记
                data.elScroll = elScroll;
                
                // 垂直位置标记
                data.posY = events.pageY;
                data.scrollY = elScroll.scrollTop();
                // 是否可以滚动
                data.maxscroll = elScroll[0].scrollHeight - elScroll[0].clientHeight;
            },
            touchmove: function () {
                // 如果不足于滚动，则禁止触发整个窗体元素的滚动
                if (data.maxscroll <= 0 || isSBBrowser) {
                    // 禁止滚动
                    event.preventDefault();
                }
                // 滚动元素
                var elScroll = data.elScroll;
                // 当前的滚动高度
                var scrollTop = elScroll.scrollTop();
        
                // 现在移动的垂直位置，用来判断是往上移动还是往下
                var events = event.touches[0] || event;
                // 移动距离
                var distanceY = events.pageY - data.posY;
        
                if (isSBBrowser) {
                    elScroll.scrollTop(data.scrollY - distanceY);
                    elScroll.trigger('scroll');
                    return;
                }
        
                // 上下边缘检测
                if (distanceY > 0 && scrollTop == 0) {
                    // 往上滑，并且到头
                    // 禁止滚动的默认行为
                    event.preventDefault();
                    return;
                }
        
                // 下边缘检测
                if (distanceY < 0 && (scrollTop + 1 >= data.maxscroll)) {
                    // 往下滑，并且到头
                    // 禁止滚动的默认行为
                    event.preventDefault();
                    return;
                }
            },
            touchend: function () {
                data.maxscroll = 0;
            }    
        });
    
        // 防止多次重复绑定
        container.data('isBindScroll', true);
    };

    module.exports = window.privateSpaceMKT.myUtils = myUtils;
});