/**
 * 手机前端Service层调用接口
 */
define("huaxiWheel/services/investService.js", function (require, exports, module) {
    var global = $.config.global;
    var service = new $.service;
    var ssoUtils= require("ssoUtils");
    require("endecryptUtils");
    require("des");

    var mobileService = {
        "destroy": function () {
            service.destroy();
        }
    };

    /********************************应用接口开始********************************/

    /**
     * @description 获取rsa加密模块和公钥(1000000)
     * @param param {Object} 入参对象集合 为空
     * @param callback 回调函数
     * 回调函数参数data.results：
     * {
     *    "modulus"        : {string}
     *    "publicExponent" : {string}
     * }
     * @param ctrlParam {Object} ajax控制参数
     */
    mobileService.getRSAKey = createFunc(function (param) {
        return {"funcNo": "1000000"};
    });


    // 获取头像的base64数据(1000001)
    mobileService.getBase64OfPhoto = createFunc(function (param) {
        return {
            "funcNo"  : "1000001",
            "photoUrl": param.photoUrl,           // 头像的URL  Y
            "content" : param.content             // 二维码内容
        };
    });

    // 查询数据字典(1101000)
    mobileService.getDataDict = createFunc(function (param) {
        return {
            "funcNo"   : "1101000",
            "enumType" : param.enumType,      // 数字字典类型 N
            "itemName" : param.itemName,      // 数据字典名称 N
            "itemValue": param.itemValue      // 数据字典值   N
        };
    });

    //查询用户剩余参与次数
    mobileService.selectLeftAttendCount = createFunc(function (param) {
        return {
            "funcNo"     : "1201901",
            "employeeNo" : param.employeeNo,        //用户id
        };
    });
    //查询奖池金额
    mobileService.queryAmount = createFunc(function (param) {
        return {
            "funcNo"     : "1201902"
        };
    });
    //查询用户中奖信息
    mobileService.queryRecord = createFunc(function (param) {
        return {
            "funcNo"     : "1201903",
            "employeeNo" : param.employeeNo      //用户id
        };
    });
    
    mobileService.queryAllPrizeUser = createFunc(function (param) {
        return {
            "funcNo"     : "1201904",
            "startDate"  : param.startDate,
            "endDate"    : param.endDate
        };
    });
    
    mobileService.attend = createFunc(function (param) {
        return {
            "funcNo"     : "1201905",
            "employeeNo" : param.employeeNo
        };
    });
    
    mobileService.queryAllSJUser = createFunc(function (param) {
        return {
            "funcNo"     : "1201906",
            "startDate"    : param.startDate,
            "endDate"    : param.endDate
        };
    });
    
    mobileService.querySJRecord = createFunc(function (param) {
        return {
            "funcNo"     : "1201907",
            "employeeNo" : param.employeeNo
        };
    });
    
    mobileService.getUserInfo = createFunc(function (param) {
        return {
            "funcNo"     : "1201908",
            "employeeNo" : param.employeeNo
        };
    });
    mobileService.queryAttend = createFunc(function (param) {
        return {
            "funcNo"     : "1201909",
            "act_no" : param.act_no
        };
    });
    mobileService.attendDraw = createFunc(function (param) {
        return {
            "funcNo"     : "1201910",
            "employeeNo" : param.employeeNo,
            "act_no" : param.act_no
        };
    });
    mobileService.addAttend = createFunc(function (param) {
        return {
            "funcNo"     : "1201911",
            "act_no" : param.act_no
        };
    });
    mobileService.selectLeftDrawCount = createFunc(function (param) {
        return {
            "funcNo"     : "1201912",
            "act_no" : param.act_no,
            "employeeNo" : param.employeeNo
        };
    });
    /********************************应用接口结束********************************/
    /**
     * 把URL参数解析为一个对象
     * @url地址
     * */
    function parseQueryString(url){
        var items=url.split("&");
        var result={};
        for(var i=0,len=items.length;i<len; i++){
            var obj = items[i];
            var startIndex = obj.indexOf('=');
            var key = obj.substring(0,startIndex);
            var value = obj.substring(startIndex+1);
            result[key] = value;
        }

        return result;
    }

    /********************************公共代码部分********************************/

    function commonInvoke(paramMap, callback, ctrlParam, reqParamVo) {
        // platform   "0": pc或手机浏览器; "1": android;  "2" :ios
        // op_source  "5": 手机浏览器H5;   "3": android;  "4" ios
        paramMap.op_source = ["5", "3", "4"][$.config.platform];

        if (!reqParamVo) {
            reqParamVo = service.reqParamVo;
            reqParamVo.setUrl(global.serverPath);
        }

        reqParamVo.setReqParam(paramMap);
        ctrlParam = ctrlParam ? ctrlParam : {};
        reqParamVo.setIsLastReq(ctrlParam.isLastReq);
        reqParamVo.setIsAsync(ctrlParam.isAsync);
        reqParamVo.setIsShowWait(ctrlParam.isShowWait);
        reqParamVo.setTimeOutFunc(ctrlParam.timeOutFunc);
        reqParamVo.setErrorFunc(ctrlParam.errorFunc);
        reqParamVo.setIsShowOverLay(ctrlParam.isShowOverLay);
        reqParamVo.setTipsWords(ctrlParam.tipsWords);
        reqParamVo.setDataType(ctrlParam.dataType);
        reqParamVo.setIsGlobal(ctrlParam.isGlobal);
        reqParamVo.setProtocol(ctrlParam.protocol);
        reqParamVo.setCacheTime(ctrlParam.cacheTime);      // 这两行代码必须加上，且不传值，这样框架就不会缓存接口返回的数据。
        reqParamVo.setCacheType(ctrlParam.cacheType);      // 如果没有这两行代码，或是传某个值的话就会缓存接口返回的数据。
        if(global.isSign == 1)
        {
            var param = reqParamVo.getReqParam();
            var bizcode = param['funcNo'];
            var funcs=global.fileterFuncs;
            if(funcs.indexOf(bizcode)==-1){
                delete param['funcNo'];
                $.ssoUtils.checkCookieValidity();
                var signStr = $.ssoUtils.ssoSignFunc(bizcode,param);
                var param = parseQueryString(signStr);
                reqParamVo.setReqParam(param);
            }
        }
        service.invoke(reqParamVo, callback);
    }

    function createFunc(insertParamFunc) {
        return function (param, successFunc, errorFunc, ctrlParam) {
            var paramMap = insertParamFunc(param);
            commonInvoke(paramMap, function (data) {
                // 处理接口返回的数据
                opDataFunc(data, successFunc, errorFunc, ctrlParam);
            }, ctrlParam);
        };
    }

    
    // 处理接口返回的数据
    // successFunc    N
    // errorFunc      N
    function opDataFunc(data, successFunc, errorFunc, ctrlParam) {
        if (data.error_no === "0") {
            if (successFunc) {
                var dsName = data.dsName;
                if (dsName.length > 1) {  // 多个结果集
                    var resultsMap = {};
                    $.each(dsName, function (index, item) {
                        resultsMap[item] = data[item];
                    });
                    successFunc(resultsMap);
                } else {
                    successFunc(data[dsName[0]],data.error_info);
                }
            }
        } else {
            if (errorFunc) {
                errorFunc(data.error_no, data.error_info);
            } else {
                $.alert(data.error_info);
            }

            // 当isLastReq配置为false（即不是最后一个请求时），
            // 如果调用接口失败，要显示关闭遮罩层
            if (ctrlParam && ctrlParam.isLastReq === false) {
                $.hidePreloader();
            }
        }
    }

    module.exports = mobileService;
});
