/**
 * 上拉加载、下拉刷新组件
 * 
 * 使用方法: 	
 * 	1、引入组件并获取实例对象，var pageSlide = require("pageSlide").getInstance();
 * 
 * 	2、在页面初始化完成后，调用init方法初始化组件
 * 		var slideOptions = {
 *				pContainer: "#slideContainer", // 父容器选择器必传 【如重构给的页面有可用的父容器直接使用即可，如果没有自己在页面上写一个div】
 *				dataContainerHtml: '<div class="fund_table" id="pdtList"></div>',  // 数据容器必传
 *				dataFunc: getDataList, // 查询方法必传
 *				pageNum: 15 // 每页显示记录数 与 分页方法参数中的参数保持一致
 *		};
 *		pageSlide.init(slideOptions);
 *
 *	3、初始化组件完成后，调用resetPageParam方法重置组件分页参数 pageSlide.resetPageParam(true); 参数isScrollTop：是否需要滚动到最上方
 *	    页面初始化时调用该方法主要是防止第二次进入页面时会记录上一次的参数以及滑动状态【另外如果页面有tab选项切换的功能，也可以调用此方法重置分页参数】
 *
 *	4、在查询数据接口完成后，调用setMaxPage方法把接口返回的最大页数赋值到组件中 
 *		pageSlide.setMaxPage(totalPages);
 *
 *	5、页面加载完数据后，调用pageScrollInit方法初始化滚动插件 
 *		pageSlide.pageScrollInit(recordLen, containerHeight);  
 *		参数recordLen: 接口返回数组长度；containerHeight：滚动插件高度，如果底部有导航栏或者其他元素时需要自己计算（不传默认为：窗口高度-容器距离顶部的距离）
 *
 *	6、如果接口没有返回数据时，调用dealEmptyData方法 处理无数据情况
 *		pageSlide.dealEmptyData(isEmpty); isEmpty=false代表有数据
 *		if(recordLen > 0) { 
 *			pageSlide.dealEmptyData(false); // 隐藏无数据div
 *		} else {
 *			pageSlide.dealEmptyData(true); // 显示无数据div
 *		}
 *
 *	7、在页面destroy方法里面调用 pageSlide.destroy()方法销毁组件
 */
define('financial/scripts/common/compts/pageSlide.js', function(require, exports, module) {
	var VIscroll = require("cusVIscroll"); // 自定义滑动组件
	/**
	 * 描述: 
	 * @author 汪卫中
	 * @param pContainer 容器父选择器 必填
	 * @param container 分页容器id 非必填
	 * @param wrapper 上下滑动区域容器id 非必填
	 * @param dataContainerHtml 数据容器元素【完整的html】必填，否则数据样式会有问题
	 * @param dataFunc 查询数据的回调函数 必填
	 * 
	 */
	function pageSlide(){
		// 组件参数
		var dftOpt = {
				pContainer: "",
				dataContainerHtml: "",
				pageNum: 20,
				dataFunc: null,
				noDataStyle: "",
				noDataText: "暂无数据"
		};
		
		// 分页参数
		var pageParams = {
				vIscroll: {"scroll" : null, "_init" : false},
				curPage: 1,
				maxPage: 0
		};
		
		// 当前页面ID
		var _pageId = $.getCurrentPageObj().pageId;

		// 初始化
		this.init = function(opt){
			// 合并外部入参
			$.extend(dftOpt, opt);
			
			// 该页面是否已经初始化过
			if ($("#" + _pageId + " #slide_container").length > 0) {
				return false;
			}
			
			var noDataStyle = dftOpt.noDataStyle;
			
			// 上下滑动容器元素
			var slideHtml = '<div id="slide_container">\
					            <div class="empty_box" style="display:none;margin-top:0rem;text-align: center;line-height: 150px; '+ noDataStyle +'">\
					                <strong>'+ dftOpt.noDataText +'</strong>\
					            </div>\
								<div class="visc_wrapper " id="slide_wrapper" data-iscrollPageId="'+ _pageId +'" >\
									<div class="visc_scroller">\
										<div class="visc_pullDown_new" style="display: none;">\
											<span class="visc_pullDownIcon_new">\
											</span>\
											<div class="visc_pullDownDiv_new">\
												<span class="visc_pullDownLabel">下拉可以刷新</span>\
											</div>\
										</div>'+ dftOpt.dataContainerHtml +'\
									    <div class="visc_pullUp_new" style="display: none;">\
											<span class="visc_pullUpIcon_new">\
											</span>\
											<div class="visc_pullUpDiv_new">\
												<span class="visc_pullUpLabel">上拉加载更多数据</span>\
											</div>\
										</div>\
										<div class="visc_no_data" style="display: none;">\
											<span>没有更多数据了</span>\
										</div>\
									</div>\
								</div>\
							</div>';
			$("#" + _pageId + " " + dftOpt.pContainer).append(slideHtml);
		};
		
		/**
		 * 理财列表分页 -> 上下滑动刷新事件
		 */
		this.pageScrollInit = function(recordLen, visibleHeight){
			var pageIdSelector = "#" + _pageId + " ";
			if (!visibleHeight) {
				var cTop = $(pageIdSelector + " #slide_container").offset().top;
				visibleHeight = $(window).height() - cTop;
			}
			if(!pageParams.vIscroll._init) {
				// 解决插件被销毁后，重新进入页面时“下拉刷新”会闪的问题
				$(pageIdSelector + "#slide_wrapper").attr("style", "");
				
				var config = {
					"isPagingType": false,
					"visibleHeight": visibleHeight, //这个是中间数据的高度
					"container": $(pageIdSelector + "#slide_container"),
					"wrapper": $(pageIdSelector + "#slide_wrapper"),
					"downHandle": function() {
						// 当前第几页设置为1
						pageParams.curPage = 1;
						dftOpt.dataFunc(false);
					},
					"upHandle": function() {
						// 如果已经是最后一页了，无需再调用加载数据的方法
						if(pageParams.curPage == pageParams.maxPage){
//							setTimeout(function(){
								pageParams.vIscroll.scroll.refresh();
//							}, 300);
							return false;
						}
						
						if(pageParams.curPage < pageParams.maxPage){
							// 当前第几页 加 1，同时调用方法加载数据
							pageParams.curPage += 1;
							dftOpt.dataFunc(true);
						}	
					},
					"wrapperObj": null
				};
				pageParams.vIscroll.scroll = new VIscroll(config); //初始化
				pageParams.vIscroll._init = true;
			}else{
				pageParams.vIscroll.scroll.refresh();
			}
			
			if(recordLen < dftOpt.pageNum || pageParams.curPage == pageParams.maxPage){
				// 已经是最后一页是，隐藏“上拉加载更多数据” 
				setTimeout(function(){
					$(pageIdSelector + "#slide_container .visc_pullUp_new").hide();
				}, 0);
				
				// 如果当前数据比较少，没有占满整个屏时无需显示 “没有更多数据”提示
				if ($(pageIdSelector + "#slide_container .visc_scroller").height() > $(pageIdSelector + "#slide_container").height()) {
					$(pageIdSelector + "#slide_container .visc_no_data").show();
				} else {
					$(pageIdSelector + "#slide_container .visc_no_data").hide();
				}
			}else{
				// 如果还有下一页数据时，隐藏“没有更多数据” 显示 “上拉加载更多数据”
				$(pageIdSelector + "#slide_container .visc_no_data").hide();
				$(pageIdSelector + "#slide_container .visc_pullUp_new").show();
			}	
		};
		
		/**
		 * 重置分页参数
		 * @param isScrollTop : 重置参数时，是否需要滚动到最上方
		 */
		this.resetPageParam = function(isScrollTop){
			pageParams.curPage = 1;
			pageParams.maxPage = 0;
			$("#"+ _pageId + " #slide_container .visc_pullUp_new").hide();
			$("#"+ _pageId + " #slide_container .visc_no_data").hide();
			$("#"+ _pageId + " .empty_box").hide();
			if (isScrollTop) {
				this.scrollTop();
			}
		};
		
		/**
		 * 设置最大页数
		 * 		接口调用成功后需要，把最大页数赋值到组件中
		 */
		this.setMaxPage = function(num){
			pageParams.maxPage = num;
		};
		
		/**
		 * 获取当前参数
		 * 		接口中当前页，需要使用这个接口获取
		 */
		this.getCurPage = function(){
			return pageParams.curPage;
		};
		
		/**
		 * 滚动到最上方
		 */
		this.scrollTop = function(){
			// 初始化滚动到最上方
			if (pageParams.vIscroll.scroll) {
				pageParams.vIscroll.scroll.getWrapperObj().scrollTo(0, -40);
			}
		};
		
		/**
		 * 处理空数据情况
		 * 1、隐藏“上拉加载更多数据”和“没有更多数据”，显示无数据提示
		 * 2、隐藏“无数据提示”
		 */
		this.dealEmptyData = function(isEmpty){
			if (isEmpty) {
				$("#" + _pageId + " #slide_container .visc_pullUp_new").hide();
				$("#" + _pageId + " #slide_container .visc_no_data").hide();
				$("#" + _pageId + " .empty_box").show();
			} else {
				$("#" + _pageId + " .empty_box").hide();
			}
		};
		
		/**
		 * 销毁方法
		 */
		this.destroy = function(){
			if (pageParams.vIscroll.scroll) {
				pageParams.vIscroll.scroll.destroy();
				pageParams.vIscroll.scroll = null;
				pageParams.vIscroll._init = false;
				$("#"+ _pageId + " #slide_container .visc_pullUp_new").hide();
				$("#"+ _pageId + " #slide_container .visc_pullDown_new").hide();
				$("#"+ _pageId + " #slide_container .visc_no_data").hide();
				$("#"+ _pageId + " .empty_box").hide();
			}
		};
	}
	
	/**
	 * 获取对象实例
	 */
	function getInstance(){
		return new pageSlide();
	}
	
	var pageSlideObj = {
			getInstance : getInstance
	};

	//暴露对外的接口
	module.exports = pageSlideObj;
});